---
title: A Primer on Canadian Government
excerpt: Canada’s parliamentary system explained.
tags: ["canada", "government"]
favourite: true
---

In the last four years I’ve learned an awful lot about how the United States’ government functions at a high level, and even on specifics like the House and Senate processes. Meanwhile I’m foggy at best on how Canada’s government functions. I decided to educate myself.

I will try my best to simplify into smaller chunks and focus on aspects I wasn’t aware of. This is not an exhaustive summary but more of a high-level overview. I’ve linked to the sources I’ve used which provides more information on specific subjects or terms.

## How is the federal government formed?

- A general election is held. This is every 4 years but can happen sooner under certain circumstances.
- When voting in a general election, Canadians are voting for an individual to represent their constituency (or riding) in the House of Commons.
- The House of Commons is the 338 elected members of parliament (MPs) across Canada. There are 338 seats in the House of Commons.
- The political party that holds the most seats in the House of Commons is the party in power.
- The power is decided in two ways: majority or minority.
- Majority power means the party in power holds more than 50% of all seats in the House of Commons.
- Minority power means the party holds the most seats, but less than 50% of the total seats in the House of Commons.
- The distinction of power is important because a majority vote is required to pass legislation.
- MPs in Canada almost always vote along party lines. When a party votes for (or against) legislation, it’s expected every member of the party will vote the same.
- Majority power governments therefore can pass legislation without challenge, while minority governments require support from other parties.
- The leader of the party in power becomes the Prime Minister.
- The Prime Minister, along with their Cabinet and the Governor General form the Executive Branch of government.
- The Prime Minister selects members of their Cabinet (ministers) and appointments them to various governmental departments.
- The Governor General appoints members of the Senate with advice from the Prime Minister. These senators come from the Prime Minister’s party.
- With the Senate filled and the House of Commons members elected, the Legislative Branch of government is formed.
- The government is ready to govern.

## What happens in the House of Commons?

- MPs spend their time in the House of Commons discussing and debating Chamber Business.
- Chamber Business tends to be new bills being put forth by ministers. MPs will sometimes put forward their own bills called Private Member’s Bills.
- There is time for MPs to talk about important information in their riding, and raise issues.
- The House of Commons has a Speaker whose job is to ensure the rules of the House are followed. Questions and statements are directed through the Speaker.

## What happens in The Senate?

- The Senate follows similarly to the House of Commons.
- Chamber business for the Senate tends to be bills originating from the House of Commons. They can discuss committee reports, make statements, etc.
- Much like the House of Commons, the Senate will debate and discuss bills.
- Although they follow the same process as the House of Commons, the Senate in Canada is not known to go against the House of Commons. A bill that passes in the House of Commons will likely pass in the Senate (occasionally with minor revisions).
- The Senate has a Speaker that functions like the House of Commons.

## What are political parties like in Canada?

- Unlike the US, Canada has more than 2 major political parties.
- In modern political history Canada has 5 major parties:
  - Liberal Party of Canada
  - Conservative Party of Canada (colloquially known as the Tories)
  - Bloc Québécois
  - New Democratic Party
  - Green Party
- MPs belong to a political party, but in rare cases can be independent.

## How does an idea become law?

- A written idea becomes a bill.
- A bill starts off in a Chamber (the House of Commons, but could be the Senate).
- It is put forward and given a First Reading. This serves as an introduction.
- Following the reading, MPs debate the bill. This process is the Second Reading.
- The bill is then passed to a committee to study and review the bill under scrutiny. This is where amendments are recorded.
- The committee then reports back to the Chamber where the bill originated, and notes any amendments. The bill is again debated. Any members not on the committee are welcome to suggest further changes.
- Following the debate and after any additional amendments are added, the bill is given its final reading called the Third Reading.
- MPs can debate one last time about the final status of the bill. MPs may change their mind in between these stages if they are for or against the bill.
- The bill is put to a vote. A vote of more than 50% means the bill moves along to the Senate, where the First, Second, and Third Reading process repeats.
- As mentioned earlier, the Canadian Senate rarely goes against what the House of Commons puts forward.
- Once the bill passes both the House of Commons and the Senate unchanged, it is ready for the Governor General.
- The Governor General gives the bill Royal Assent, and it becomes law.
- The Governor General represents the Queen and thus holds ultimate power, but has never withheld Royal Assent in modern politics. This part of the process is ceremonial.

## Watch sessions of Parliament

You may be familiar with C-SPAN which offers live streams of US House and Senate sessions. There is a Canadian equivalent called [CPAC][cpac] (Cable Public Affairs Channel) which offers similar programming. CPAC is a privately owned, not-for-profit television service. It’s designed to be an unbiased window into our government at work.

The [House of Commons publishes their agenda][hocagenda] for the day.

## Who’s working for you?

The [House of Commons site has the list][hocmembers] of every elected MP. Each member has information on their roles, any bills they have supported or put forward, how they have voted on matters, and more. It even shows where they are seated in the House of Commons! There are detailed breakdowns on current and past roles, election results, and more.

## Conclusion

Keep in mind this was a surface level introduction into Canadian government. There are more details to learn like:

- What are the rules in the House of Commons? The Senate?
- What are the political party ideologies?
- What about provincial governments?
- What are the requirements to become a Senator?
- What is the pathway for a Canadian citizen to become an MP?
- How do the smaller political parties pass legislation?

My hope though is this is enough of a jumping-off point to kick-start the process of learning more and getting involved in Canadian politics.

## Sources

[House of Commons Canada — “The Canadian Parliamentary System“](https://www.ourcommons.ca/About/OurProcedure/ParliamentaryFramework/c_g_parliamentaryframework-e.htm)

[House of Commons Canada — “Legislative Process”](https://www.ourcommons.ca/About/OurProcedure/LegislativeProcess/c_g_legislativeprocess-e.htm)

[cpac]: https://www.cpac.ca/en/
[hocagenda]: https://www.ourcommons.ca/en#pw-agenda-publications
[hocmembers]: https://www.ourcommons.ca/members/en
